import {
  Avatar,
  Box,
  Button,
  Card,
  CardBody,
  CardFooter,
  CardHeader,
  Center,
  HStack,
  Heading,
  Icon,
  Input,
  Text,
  VStack,
} from '@chakra-ui/react'
import { FaRegStar, FaStar } from 'react-icons/fa6'
import React, { memo, useState } from 'react'

import { FormTest } from './from'
import { Stars } from '../stars'

type User = Record<string, unknown> & {
  id: string
  name: string
  avatar?: string
  rated: number
  friends?: User[]
}

export const Profile = ({
  user,
  isLink,
  title,
}: {
  user: User
  isLink?: boolean
  title?: string
}) => {
  const [rated, setRated] = useState(user.rated || 0)

  return (
    <Box mt={3} borderWidth="1px" p={3} overflowX="hidden">
      {!isLink && <FormTest />}
      <Heading as="h2">{title || 'Данные профиля'}</Heading>
      <Box m={3}>
        <Card width={'fit-content'} shadow="2xl">
          <CardHeader>
            <Center>
              <Avatar size="xl" pt={1} src={user.avatar as string} />
            </Center>
          </CardHeader>
          <CardBody>
            <Text fontWeight="bold">Имя: {user.name.toUpperCase()}</Text>
          </CardBody>
          <CardFooter>
            <Stars rated={rated} setRated={setRated} />
          </CardFooter>
        </Card>
      </Box>
      {!isLink && <Counter value={rated} setValue={setRated} />}
    </Box>
  )
}

const Form = memo<{ initialState: string; onSubmit(value: string): void }>(
  ({ initialState, onSubmit }) => {
    const [message, setMessage] = useState(initialState)

    const handleMessageChange = (event) => {
      setMessage(event.target.value)
    }

    return (
      <Box mt={3} mb={3}>
        <Text fontWeight="bold">Написать сообщение:</Text>

        <form
          onSubmit={(event) => {
            event.preventDefault()
            onSubmit(message)
          }}
        >
          <Box
            bg="gray.100"
            p={4}
            borderRadius={3}
            borderWidth={1}
            mt={3}
            mb={3}
            rounded="md"
          >
            <label htmlFor="message">Сообщение:</label>
            <Input
              placeholder="Отпавим весточку?"
              value={message}
              onChange={handleMessageChange}
              id="message"
            />
          </Box>
          <Button type="submit">Отправить</Button>
        </form>
      </Box>
    )
  },
)

Form.displayName = 'FormMemo'

const Counter = ({ value, setValue, horiaontal = false }) => {
  const Wrapper = horiaontal ? HStack : VStack

  return (
    <Center>
      <Wrapper>
        <Heading>{value}</Heading>

        <Button onClick={() => setValue(value + 1)}>+</Button>
        <Button onClick={() => setValue(value - 1)}>-</Button>
      </Wrapper>
    </Center>
  )
}
